Enum Kilo

enum Kilo

Holds the standard to use when displaying the size.

Variants

Decimal

The decimal scale and units. SI standard.

Binary

The binary scale and units.

Implementations

impl Clone for Kilo

fn clone(self: &Self) -> Kilo

impl Copy for Kilo

impl Debug for Kilo

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Default for Kilo

fn default() -> Kilo

impl Eq for Kilo

impl Freeze for Kilo

impl PartialEq for Kilo

fn eq(self: &Self, other: &Kilo) -> bool

impl RefUnwindSafe for Kilo

impl Send for Kilo

impl StructuralPartialEq for Kilo

impl Sync for Kilo

impl Unpin for Kilo

impl UnsafeUnpin for Kilo

impl UnwindSafe for Kilo

impl<T> Any for Kilo

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Kilo

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Kilo

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Kilo

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Kilo

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Kilo

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Kilo

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Kilo

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Kilo

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>